Stan Math Library: stan/math/prim/scal/err/check_not_nan.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

check_not_nan.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_ERR_CHECK_NOT_NAN_HPP
2 #define STAN_MATH_PRIM_SCAL_ERR_CHECK_NOT_NAN_HPP
3
4 #include <stan/math/prim/scal/meta/length.hpp>
5 #include <stan/math/prim/scal/meta/is_vector_like.hpp>
6 #include <stan/math/prim/scal/err/domain_error.hpp>
7 #include <stan/math/prim/scal/err/domain_error_vec.hpp>
8 #include <stan/math/prim/scal/fun/value_of_rec.hpp>
9 #include <boost/math/special_functions/fpclassify.hpp>
10
11
12 namespace stan {
13 namespace math {
14
15 namespace {
16 template <typename T_y, bool is_vec>
17 struct not_nan {
18 static bool check(const char* function,
19 const char* name,
20 const T_y& y) {
21 using stan::math::value_of_rec;
22 if ((boost::math::isnan)(value_of_rec(y)))
23 domain_error(function, name, y,
24 "is ", ", but must not be nan!");
25 return true;
26 }
27 };
28
29 template <typename T_y>
30 struct not_nan<T_y, true> {
31 static bool check(const char* function,
32 const char* name,
33 const T_y& y) {
34 using stan::math::value_of_rec;
35 for (size_t n = 0; n < stan::length(y); n++) {
36 if ((boost::math::isnan)(value_of_rec(stan::get(y, n))))
37 domain_error_vec(function, name, y, n,
38 "is ", ", but must not be nan!");
39 }
40 return true;
41 }
42 };
43 }
44
62 template <typename T_y>
63 inline bool check_not_nan(const char* function,
64 const char* name,
65 const T_y& y) {
66 return not_nan<T_y, is_vector_like<T_y>::value>
67 ::check(function, name, y);
68 }
69
70 }
71 }
72 #endif
stan::math::check_not_nan
bool check_not_nan(const char *function, const char *name, const T_y &y)
Return true if y is not NaN.
Definition: check_not_nan.hpp:63
stan
Definition: log_sum_exp.hpp:8
stan::math::value_of_rec
double value_of_rec(const fvar< T > &v)
Return the value of the specified variable.
Definition: value_of_rec.hpp:21
stan::length
size_t length(const std::vector< T > &x)
Definition: length.hpp:10
domain_error_vec.hpp
boost::math::isnan
bool isnan(const stan::math::var &v)
Checks if the given number is NaN.
Definition: boost_isnan.hpp:22
is_vector_like.hpp
stan::math::domain_error_vec
void domain_error_vec(const char *function, const char *name, const T &y, const size_t i, const char *msg1, const char *msg2)
Throw a domain error with a consistently formatted message.
Definition: domain_error_vec.hpp:38
stan::get
T get(const std::vector< T > &x, size_t n)
Definition: get.hpp:10
stan::math::domain_error
void domain_error(const char *function, const char *name, const T &y, const char *msg1, const char *msg2)
Throw a domain error with a consistently formatted message.
Definition: domain_error.hpp:32
value_of_rec.hpp
length.hpp
domain_error.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.